SVMLight

Struct SVMLight 

pub struct SVMLight;
The default implementation of SVMLight parsing is based on the SVM-light format.

The format is as follows:

Implementations

Source

impl SVMLight

pub fn load_datapoint(buffer: &str) -> Result<DataPoint, LtrError>

Load a single DataPoint from a line of the SVMLight format.

The format is as follows:

Arguments
  • buffer - The buffer containing the SVMLight formatted data point.
Returns

A DataPoint with the data loaded from the buffer.

Errors

If the buffer is not in the correct format, an error is returned.

pub fn load_ranklist(buffer: &str) -> Result<RankList, LtrError>

Load a RankList from a SVM-Light buffer. Notice that this method DOES NOT check whether the RankList has different query ids. If you’re not sure, use the load_dataset method.

The format is as follows: \n \n … \n

Arguments
  • buffer - The buffer containing the SVMLight formatted rank list.
Returns

A RankList with the data loaded from the buffer.

Errors

If the buffer is not in the correct format, an error is returned.

pub fn load_dataset(buffer: &str) -> Result<DataSet, LtrError>

Load a DataSet from a SVM-Light buffer.

Arguments
  • buffer - The buffer containing the SVMLight formatted dataset.
Returns

A DataSet with the data loaded from the buffer.